@@ -147,11 +147,17 @@
 /*	int	warn_compat_break_flush_domains;
 /*	int	warn_compat_break_mynetworks_style;
 /*
+/*	int	warn_compat_break_smtpd_tls_fpt_dgst;
+/*	int	warn_compat_break_smtp_tls_fpt_dgst;
+/*	int	warn_compat_break_lmtp_tls_fpt_dgst;
+/*
 /*	char	*var_maillog_file;
 /*	char	*var_maillog_file_pfxs;
 /*	char	*var_maillog_file_comp;
 /*	char	*var_maillog_file_stamp;
 /*	char	*var_postlog_service;
+/*
+/*	char	*var_dnssec_probe;
 /* DESCRIPTION
 /*	This module (actually the associated include file) defines
 /*	the names and defaults of all mail configuration parameters.
@@ -356,14 +362,23 @@ char   *var_drop_hdrs;
 char   *var_info_log_addr_form;
 bool    var_enable_orcpt;
 
-char	*var_maillog_file;
-char	*var_maillog_file_pfxs;
-char	*var_maillog_file_comp;
-char	*var_maillog_file_stamp;
-char	*var_postlog_service;
+char   *var_maillog_file;
+char   *var_maillog_file_pfxs;
+char   *var_maillog_file_comp;
+char   *var_maillog_file_stamp;
+char   *var_postlog_service;
+
+char   *var_dnssec_probe;
 
 const char null_format_string[1] = "";
 
+ /*
+  * Compatibility level 3.
+  */
+int     warn_compat_break_smtpd_tls_fpt_dgst;
+int     warn_compat_break_smtp_tls_fpt_dgst;
+int     warn_compat_break_lmtp_tls_fpt_dgst;
+
  /*
   * Compatibility level 2.
   */
@@ -618,6 +633,23 @@ static void check_legacy_defaults(void)
      * bits.
      */
 
+    /*
+     * Look for specific parameters whose default changed when the
+     * compatibility level changed to 3.
+     */
+    if (var_compat_level < 3) {
+	if (mail_conf_lookup(VAR_SMTPD_TLS_FPT_DGST) == 0)
+	    warn_compat_break_smtpd_tls_fpt_dgst = 1;
+	if (mail_conf_lookup(VAR_SMTP_TLS_FPT_DGST) == 0)
+	    warn_compat_break_smtp_tls_fpt_dgst = 1;
+	if (mail_conf_lookup(VAR_LMTP_TLS_FPT_DGST) == 0)
+	    warn_compat_break_lmtp_tls_fpt_dgst = 1;
+    } else {
+	warn_compat_break_smtpd_tls_fpt_dgst = 0;
+	warn_compat_break_smtp_tls_fpt_dgst = 0;
+	warn_compat_break_lmtp_tls_fpt_dgst = 0;
+    }
+
     /*
      * Look for specific parameters whose default changed when the
      * compatibility level changed to 2.
@@ -689,6 +721,7 @@ void    mail_params_init()
 	VAR_MAILLOG_FILE_COMP, DEF_MAILLOG_FILE_COMP, &var_maillog_file_comp, 1, 0,
 	VAR_MAILLOG_FILE_STAMP, DEF_MAILLOG_FILE_STAMP, &var_maillog_file_stamp, 1, 0,
 	VAR_POSTLOG_SERVICE, DEF_POSTLOG_SERVICE, &var_postlog_service, 1, 0,
+	VAR_DNSSEC_PROBE, DEF_DNSSEC_PROBE, &var_dnssec_probe, 0, 0,
 	0,
     };
     static const CONFIG_BOOL_TABLE first_bool_defaults[] = {
@@ -871,6 +904,8 @@ void    mail_params_init()
     var_smtputf8_enable = 0;
 #else
     midna_domain_transitional = var_idna2003_compat;
+    if (var_smtputf8_enable)
+	midna_domain_pre_chroot();
 #endif
     util_utf8_enable = var_smtputf8_enable;
 
