@@ -261,10 +261,8 @@ static int check_login_sender_acl(uid_t uid, VSTRING *sender_buf,
     /*
      * Optimization.
      */
-#ifndef SNAPSHOT
     if (strcmp(var_local_login_snd_maps, DEF_LOCAL_LOGIN_SND_MAPS) == 0)
 	return (CLEANUP_STAT_OK);
-#endif
 
     /*
      * Get the username.
@@ -273,7 +271,7 @@ static int check_login_sender_acl(uid_t uid, VSTRING *sender_buf,
 	user_name = user_info->pw_name;
     } else {
 	user_name_buf = vstring_alloc(10);
-	vstring_sprintf(user_name_buf, "uid:%ld", (long) uid);
+	vstring_sprintf(user_name_buf, "#%ld", (long) uid);
 	user_name = vstring_str(user_name_buf);
     }
 
